==> ideaIC-141.1192.2-sources.jar: com/intellij/util/io/socketConnection/SocketConnectionFactory.java <==
/*
 * Copyright 2000-2010 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.util.io.socketConnection;

import com.intellij.util.io.socketConnection.impl.ServerSocketConnectionImpl;
import com.intellij.util.io.socketConnection.impl.SocketConnectionImpl;
import org.jetbrains.annotations.Nullable;

import java.net.InetAddress;

/**
 * @author nik
 */
public class SocketConnectionFactory {
  private SocketConnectionFactory() {
  }

  public static <Request extends AbstractRequest, Response extends AbstractResponse>
    SocketConnection<Request, Response> createServerConnection(int defaultPort, int attempts, RequestResponseExternalizerFactory<Request, Response> factory) {
    return new ServerSocketConnectionImpl<Request, Response>(defaultPort, attempts, factory);
  }


  public static <Request extends AbstractRequest, Response extends AbstractResponse>
    SocketConnection<Request, Response> createServerConnection(int defaultPort, RequestResponseExternalizerFactory<Request, Response> factory) {
    return new ServerSocketConnectionImpl<Request, Response>(defaultPort, 1, factory);
  }

  public static <Request extends AbstractRequest, Response extends AbstractResponse>
  ClientSocketConnection<Request, Response> createConnection(final @Nullable InetAddress host, int initialPort,
                                                             int portsNumberToTry,
                                                             RequestResponseExternalizerFactory<Request, Response> factory) {
    return new SocketConnectionImpl<Request, Response>(host, initialPort, portsNumberToTry, factory);
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/util/io/socketConnection/SocketConnectionFactory.java <==
/*
 * Copyright 2000-2010 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.util.io.socketConnection;

import com.intellij.util.io.socketConnection.impl.ServerSocketConnectionImpl;
import com.intellij.util.io.socketConnection.impl.SocketConnectionImpl;
import org.jetbrains.annotations.Nullable;

import java.net.InetAddress;

/**
 * @author nik
 */
public class SocketConnectionFactory {
  private SocketConnectionFactory() {
  }

  public static <Request extends AbstractRequest, Response extends AbstractResponse>
    SocketConnection<Request, Response> createServerConnection(int defaultPort, int attempts, RequestResponseExternalizerFactory<Request, Response> factory) {
    return new ServerSocketConnectionImpl<>(defaultPort, attempts, factory);
  }


  public static <Request extends AbstractRequest, Response extends AbstractResponse>
    SocketConnection<Request, Response> createServerConnection(int defaultPort, RequestResponseExternalizerFactory<Request, Response> factory) {
    return new ServerSocketConnectionImpl<>(defaultPort, 1, factory);
  }

  public static <Request extends AbstractRequest, Response extends AbstractResponse>
  ClientSocketConnection<Request, Response> createConnection(final @Nullable InetAddress host, int initialPort,
                                                             int portsNumberToTry,
                                                             RequestResponseExternalizerFactory<Request, Response> factory) {
    return new SocketConnectionImpl<>(host, initialPort, portsNumberToTry, factory);
  }
}
